@@ -12,7 +12,7 @@ from SharedData.SharedDataAWSS3 import S3SyncDownloadMetadata,S3Upload
 
 class Metadata():
     
-    def __init__(self, name, mode='rw', sync_frequency_days=0.5, user='master'):
+    def __init__(self, name, mode='rw', sync_frequency_days=0, user='master'):
         if Logger.log is None:
             Logger('Metadata')
 
