@@ -10,7 +10,7 @@ from SharedData.SharedDataRealTime import SharedDataRealTime
 
 class SharedData:
     
-    def __init__(self, database, mode='rw', sync_frequency_days=0.5, user='master'):
+    def __init__(self, database, mode='rw', sync_frequency_days=0, user='master'):
         if Logger.log is None:            
             Logger('SharedData')
         
