@@ -23,14 +23,13 @@ def S3SyncDownloadDataFrame(path,shm_name):
     env['PATH'] = sys.exec_prefix+r'\Scripts'
 
     process = subprocess.Popen(['aws','s3','sync',awsfolder,dbfolder,\
-        '--profile',Logger.user,\
         '--exclude','*',\
         '--exact-timestamps',\
         '--include',shm_name.split('/')[-1]+'.json',\
         '--include',shm_name.split('/')[-1]+'.npy'],\
         stdout=subprocess.PIPE, stderr=subprocess.PIPE,\
-        universal_newlines=True, shell=True, env=env)        
-    
+        universal_newlines=True, shell=True, env=env)
+
     while True:
         output = process.stdout.readline()
         if ((output == '') | (output == b''))\
@@ -54,7 +53,6 @@ def S3SyncDownloadTimeSeries(path,shm_name):
     env = os.environ.copy()
     env['PATH'] = sys.exec_prefix+r'\Scripts'
     process = subprocess.Popen(['aws','s3','sync',awsfolder,path,\
-        '--profile',Logger.user,\
         '--exact-timestamps',\
         #'--delete',\
         '--exclude=shm_info.json'],\
@@ -92,7 +90,6 @@ def S3SyncDownloadMetadata(pathpkl,name):
     env['PATH'] = sys.exec_prefix+r'\Scripts'
 
     process = subprocess.Popen(['aws','s3','sync',awsfolder,dbfolder,\
-        '--profile',Logger.user,\
         '--exclude','*',\
         '--exact-timestamps',\
         '--include',name.split('/')[-1]+'.pkl',\
@@ -128,7 +125,7 @@ def S3Upload(localfilepath):
       
     Logger.log.debug(Logger.user+' Uploading to S3 '+str(localfilepath)+' ...')
     try:                
-        session = boto3.Session(profile_name=Logger.user)   
+        session = boto3.Session()
         s3 = session.resource('s3')
         bucket = s3.Bucket(os.environ['S3_BUCKET'].replace('s3://',''))
         bucket.upload_file(localfilepath,remotefilepath.replace(os.environ['S3_BUCKET'],'')[1:])
