@@ -13,14 +13,11 @@ class SharedDataFeeder():
     
         self.dataset = sharedData.dataset
         if len(self.dataset)>0:
-            idx = self.dataset['feeder']==feeder            
+            idx = self.dataset['feeder']==feeder
             if np.any(idx):
                 self.dataset = self.dataset[idx]
             else:
-                self.dataset = pd.DataFrame([]) 
-        else:
-            Logger.log.warning('feeder %s not found in dataset!' % (self.feeder))
-            #raise Exception('feeder not found in dataset!')
+                self.dataset = pd.DataFrame([])        
 
         # DATA DICTIONARY
         # data[period][tag]
