@@ -59,10 +59,10 @@ class SharedDataFrame:
                             lastsync.index.name = 'file'
                             lastsync.to_csv(self.sharedData.lastsyncfpath)
                     
-                    # Read
-                    df = self.Read()
-                    if not df.empty:
-                        self.Malloc(df)
+                # Read
+                df = self.Read()
+                if not df.empty:
+                    self.Malloc(df)
             
         else: # map existing dataframe   
             #drop non number fields   
@@ -195,7 +195,7 @@ class SharedDataFrame:
                         (self.database,self.feeder,self.period,self.tagstr,100,time.time()-tini))                
         return pd.DataFrame([])
 
-    def Write(self):
+    def Write(self,startDate=None):
         tini = time.time()
         Logger.log.debug('Writing %s/%s/%s/%s  ...%.2f%% ' % \
             (self.database,self.feeder,self.period,self.tagstr,0.0))        
