@@ -16,6 +16,8 @@ class SharedDataPeriod:
         self.sharedDataFeeder = sharedDataFeeder        
         self.sharedData = sharedDataFeeder.sharedData        
         self.period = period
+        self.default_startDate = None
+        self.default_collections = None
         
         # PRE REGISTERED TAGS
         self.dataset = pd.DataFrame([])
@@ -70,7 +72,7 @@ class SharedDataPeriod:
 
     def getTimeIndex(self, startDate):
         if not startDate in self.timeidx.keys():
-            nextsaturday = datetime.today() + BDay(1)\
+            nextsaturday = datetime.today() + BDay(21)\
                 + timedelta((12 - datetime.today().weekday()) % 7)
                         
             if self.period=='D1':
@@ -120,11 +122,12 @@ class SharedDataPeriod:
     
     def exists(self, tag):
         if isinstance(tag, pd.Timestamp):            
-            path = Path(os.environ['DATABASE_FOLDER'])     
-            path =  path / self.sharedData.database
-            path =  path / self.sharedDataFeeder.feeder
-            path =  path / self.period       
-            fpath =  path / (tag.strftime('%Y%m%d%H%M')+'.npy')
+            path = Path(os.environ['DATABASE_FOLDER'])
+            path = path / self.sharedData.user
+            path = path / self.sharedData.database
+            path = path / self.sharedDataFeeder.feeder
+            path = path / self.period       
+            fpath = path / (tag.strftime('%Y%m%d%H%M')+'.npy')            
             return fpath.is_file()
         else:
             return False 
