@@ -35,23 +35,29 @@ class SharedDataTimeSeries:
         self.columns = pd.Index([])
                         
         if value is None: #Read dataset tag
+            feeder = self.sharedDataFeeder.feeder            
             dataset = sharedDataPeriod.dataset
             sharedData = sharedDataPeriod.sharedData
-            feeder = self.sharedDataFeeder.feeder
         
-            if not tag in dataset.index:
-                raise ValueError('tag '+tag+' not found in dataset!')
+            if not tag in dataset.index:                
+                if (not sharedDataPeriod.default_startDate is None) \
+                    & (not sharedDataPeriod.default_collections is None):
+                    self.startDate = sharedDataPeriod.default_startDate
+                    self.collections = sharedDataPeriod.default_collections.split(',')
+                else:
+                    raise ValueError('tag '+tag+' not found in dataset!')
             else:
                 self.startDate = dataset['startDate'][tag]
                 self.collections = dataset['collections'][tag].split(',')
-                _symbols = pd.Index([])
-                for collection in self.collections:                
-                    _symbols = _symbols.union(sharedData.getSymbols(collection))   
-                    if len(_symbols)==0:
-                        raise Exception('collection '+collection+' has no symbols!')
-                _timeidx = sharedDataPeriod.getTimeIndex(self.startDate)                
-                self.index = _timeidx
-                self.columns = _symbols                                       
+
+            _symbols = pd.Index([])
+            for collection in self.collections:
+                _symbols = _symbols.union(sharedData.getSymbols(collection))
+                if len(_symbols)==0:
+                    raise Exception('collection '+collection+' has no symbols!')
+            _timeidx = sharedDataPeriod.getTimeIndex(self.startDate)
+            self.index = _timeidx
+            self.columns = _symbols
                 
             self.symbolidx = {}
             for i in range(len(self.columns)):
